from setuptools import setup

setup(
    name='colrev_core',
    version='0.0.1',
    description='',
    long_description='',
    url='',
    author='Gerit Wagner',
    author_email='gerit.wagner@hec.ca',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)
